@@ -6,11 +6,12 @@ import os
 class Generator():
   def __init__(self,id):
     self.id = str(id)
-  def toBlocks(self):
+  def toBlocks(self,path):
     '''
     Converts to scratchblocks and puts each sprites' scripts in a HTML file
     '''
     os.chdir(os.getcwd())
+    os.chdir(path)
     targets = json.loads(requests.get('https://projects.scratch.mit.edu/'+self.id).text)['targets']
 
     JSON = []
